/*
!xMeter_EA Major_5 v02.mq4
Copyright  2007, MetaQuotes Software Corp.
Price Meter System GPL

Robert Hill
   5/16/2007   Corrected problem with IBFX mini Account

traderak20@gmail.com
   1/30/2008   Changed currencies to major 5 (EUR, USD, GBP, CHF, JPY). The meter uses all 10 possible pairs
   1/30/2008   Added function objectDeleteAll() to limit deletion to only the objects created by this EA
   1/30/2008   Replaced GetPoint() function with built-in function MarketInfo(string symbol,MODE_POINT)
   1/30/2008   Default symbolnames are now without "m", for IBFX accounts the "m" is added afterwards
   1/30/2008   Changed the display of grades from a scale of 5 steps to 10 (10 were already calculated anyway)
   1/30/2008   Some minor changes to variable names, clean-up of code and cosmetic.
   1/30/2008   Renamed file from !xMeter_EA.mq4 to !xMeter_EA Major_5 v02.mq4
*/

#property copyright "x Meter System GPL"
#property link      "forex-tsd dot com"

//---- Number of pairs
#define ARRSIZE 10
//---- Number of currencies
#define PAIRSIZE 5
//---- Scale of currency's power
#define TABSIZE 10

//---- Set constant for currency pairs; added to make code easier to understand
#define CHFJPY 0
#define EURCHF 1
#define EURGBP 2
#define EURJPY 3
#define EURUSD 4
#define GBPCHF 5
#define GBPJPY 6
#define GBPUSD 7
#define USDCHF 8
#define USDJPY 9

//---- Set constant for currencies; added to make code easier to understand
#define EUR 0
#define USD 1
#define GBP 2
#define CHF 3
#define JPY 4

extern bool AccountIsIBFXmini = FALSE;

string aPair[ARRSIZE]   = {"CHFJPY","EURCHF","EURGBP","EURJPY","EURUSD",
                           "GBPCHF","GBPJPY","GBPUSD","USDCHF","USDJPY"};
string aMajor[PAIRSIZE] = {"EUR","USD","GBP","CHF","JPY"};

//+------------------------------------------------------------------+
//     expert initialization function                                |       
//+------------------------------------------------------------------+
int init()
{
//----
   initGraph();
//---- Infinite loop for main program
   while (true)
   {
      if (IsConnected()) main();
      if (!IsConnected()) objectBlank();
      WindowRedraw();
//---- Give your PC a breath
      Sleep(1000);
   }
//----
   return(0);
}
//+------------------------------------------------------------------+
//     expert deinitialization function                              |       
//+------------------------------------------------------------------+
int deinit()
{
//----
   objectDeleteAll();
   Print("shutdown error - ",GetLastError());
//----
   return(0);
}
//+------------------------------------------------------------------+
//     expert start function                                         |       
//+------------------------------------------------------------------+
int start()
{
//----

//----
   return(0);
}
//+------------------------------------------------------------------+
//     expert custom function                                        |       
//+------------------------------------------------------------------+    
void main()
{
//----
   double aMeter[PAIRSIZE];
   double aHigh[ARRSIZE];
   double aLow[ARRSIZE];
   double aClose[ARRSIZE];
   double aRatio_1[ARRSIZE];
   double aRatio_2[ARRSIZE];
   double aRange[ARRSIZE];
   double aLookup_1[ARRSIZE];
   double aLookup_2[ARRSIZE];
   double point;
   int i;
   string mySymbol;

//---- Initialize all pairs required value
   for ( i = 0; i < ARRSIZE; i++ )
   {
//---- Refresh all currency's instrument
      RefreshRates();
//---- Make naming compatible with IBFX mini accounts
      if (AccountIsIBFXmini) mySymbol = aPair[i] + "m";
      else mySymbol = aPair[i];
//---- Get a point basis
      point = MarketInfo(mySymbol,MODE_POINT);
      aHigh[i] = MarketInfo(mySymbol,MODE_HIGH);
      aLow[i] = MarketInfo(mySymbol,MODE_LOW);
      aClose[i] = MarketInfo(mySymbol,MODE_BID);
//---- Calculate today's range
      aRange[i] = MathMax( (aHigh[i] - aLow[i]) / point,1);
//---- Calculate pair's ratio and inverse ratio
      aRatio_1[i] = ( aClose[i] - aLow[i]) / aRange[i] / point;
      aRatio_2[i] = ( aHigh[i] - aClose[i]) / aRange[i] / point;
//---- Set a pair's grade and inverse grade
      aLookup_1[i] = iLookup( aRatio_1[i] * 100 );
      aLookup_2[i] = iLookup( aRatio_2[i] * 100 );
   }

//---- Calculate all currencies meter
   aMeter[EUR] = NormalizeDouble( (aLookup_1[EURCHF] + aLookup_1[EURGBP] + aLookup_1[EURJPY] + aLookup_1[EURUSD] )/4,1);
   aMeter[USD] = NormalizeDouble( (aLookup_2[EURUSD] + aLookup_2[GBPUSD] + aLookup_1[USDJPY] + aLookup_1[USDCHF] )/4,1);
   aMeter[GBP] = NormalizeDouble( (aLookup_2[EURGBP] + aLookup_1[GBPCHF] + aLookup_1[GBPJPY] + aLookup_1[GBPUSD] )/4,1);
   aMeter[CHF] = NormalizeDouble( (aLookup_1[CHFJPY] + aLookup_2[EURCHF] + aLookup_2[GBPCHF] + aLookup_2[USDCHF] )/4,1);   
   aMeter[JPY] = NormalizeDouble( (aLookup_2[CHFJPY] + aLookup_2[EURJPY] + aLookup_2[GBPJPY] + aLookup_2[USDJPY] )/4,1);

   objectBlank();
   paintEUR(aMeter[EUR]);
   paintUSD(aMeter[USD]);
   paintGBP(aMeter[GBP]);
   paintCHF(aMeter[CHF]);
   paintJPY(aMeter[JPY]);
   paintLine();
//----
}

//---- This function will return a grade value for a pair based on its power
int iLookup(double ratio)
{
//---- Grade table for currency's power
   int aTable[TABSIZE]  = {0,3,10,25,40,50,60,75,90,97};
   int index;

   if (ratio <= aTable[0]) index = 0;
   else if (ratio < aTable[1]) index = 0;
   else if (ratio < aTable[2]) index = 1;
   else if (ratio < aTable[3]) index = 2;
   else if (ratio < aTable[4]) index = 3;
   else if (ratio < aTable[5]) index = 4;
   else if (ratio < aTable[6]) index = 5;
   else if (ratio < aTable[7]) index = 6;
   else if (ratio < aTable[8]) index = 7;
   else if (ratio < aTable[9]) index = 8;
   else index = 9;

   return(index);
}
//+------------------------------------------------------------------+

void initGraph()
{
   objectDeleteAll();

   objectCreate("pms_eur_10",90,65);
   objectCreate("pms_eur_9",90,59);
   objectCreate("pms_eur_8",90,53);
   objectCreate("pms_eur_7",90,47);
   objectCreate("pms_eur_6",90,41);
   objectCreate("pms_eur_5",90,35);
   objectCreate("pms_eur_4",90,29);
   objectCreate("pms_eur_3",90,23);
   objectCreate("pms_eur_2",90,17);
   objectCreate("pms_eur_1",90,11);
   objectCreate("pms_eur_cur",92,12,"EUR",7,"Arial Narrow",SkyBlue);
   objectCreate("pms_eur_pwr",94,21,DoubleToStr(9,1),8,"Arial Narrow",Silver);

   objectCreate("pms_usd_10",70,65);
   objectCreate("pms_usd_9",70,59);
   objectCreate("pms_usd_8",70,53);
   objectCreate("pms_usd_7",70,47);
   objectCreate("pms_usd_6",70,41);
   objectCreate("pms_usd_5",70,35);
   objectCreate("pms_usd_4",70,29);
   objectCreate("pms_usd_3",70,23);
   objectCreate("pms_usd_2",70,17);
   objectCreate("pms_usd_1",70,11);
   objectCreate("pms_usd_cur",72,12,"USD",7,"Arial Narrow",SkyBlue);
   objectCreate("pms_usd_pwr",74,21,DoubleToStr(9,1),8,"Arial Narrow",Silver);

   objectCreate("pms_gbp_10",50,65);
   objectCreate("pms_gbp_9",50,59);
   objectCreate("pms_gbp_8",50,53);
   objectCreate("pms_gbp_7",50,47);
   objectCreate("pms_gbp_6",50,41);
   objectCreate("pms_gbp_5",50,35);
   objectCreate("pms_gbp_4",50,29);
   objectCreate("pms_gbp_3",50,23);
   objectCreate("pms_gbp_2",50,17);
   objectCreate("pms_gbp_1",50,11);
   objectCreate("pms_gbp_cur",52,12,"GBP",7,"Arial Narrow",SkyBlue);
   objectCreate("pms_gbp_pwr",54,21,DoubleToStr(9,1),8,"Arial Narrow",Silver);

   objectCreate("pms_chf_10",30,65);
   objectCreate("pms_chf_9",30,59);
   objectCreate("pms_chf_8",30,53);
   objectCreate("pms_chf_7",30,47);
   objectCreate("pms_chf_6",30,41);
   objectCreate("pms_chf_5",30,35);
   objectCreate("pms_chf_4",30,29);
   objectCreate("pms_chf_3",30,23);
   objectCreate("pms_chf_2",30,17);
   objectCreate("pms_chf_1",30,11);
   objectCreate("pms_chf_cur",32,12,"CHF",7,"Arial Narrow",SkyBlue);
   objectCreate("pms_chf_pwr",34,21,DoubleToStr(9,1),8,"Arial Narrow",Silver);

   objectCreate("pms_jpy_10",10,65);
   objectCreate("pms_jpy_9",10,59);
   objectCreate("pms_jpy_8",10,53);
   objectCreate("pms_jpy_7",10,47);
   objectCreate("pms_jpy_6",10,41);
   objectCreate("pms_jpy_5",10,35);
   objectCreate("pms_jpy_4",10,29);
   objectCreate("pms_jpy_3",10,23);
   objectCreate("pms_jpy_2",10,17);
   objectCreate("pms_jpy_1",10,11);
   objectCreate("pms_jpy_cur",13,12,"JPY",7,"Arial Narrow",SkyBlue);
   objectCreate("pms_jpy_pwr",14,21,DoubleToStr(9,1),8,"Arial Narrow",Silver);

   objectCreate("pms_line_top",10,91,"-------------------------",10,"Arial",DimGray);
   objectCreate("pms_line_middle",10,27,"-------------------------",10,"Arial",DimGray);
   objectCreate("pms_line_bottom",10,6,"-------------------------",10,"Arial",DimGray);
   objectCreate("pms_sign",12,1,"Price Meter System GPL",7,"Arial Narrow",DimGray);

   WindowRedraw();
}

void objectDeleteAll()
{
   ObjectDelete("pms_eur_1");
   ObjectDelete("pms_eur_2");
   ObjectDelete("pms_eur_3");
   ObjectDelete("pms_eur_4");
   ObjectDelete("pms_eur_5");
   ObjectDelete("pms_eur_6");
   ObjectDelete("pms_eur_7");
   ObjectDelete("pms_eur_8");
   ObjectDelete("pms_eur_9");
   ObjectDelete("pms_eur_10");
   ObjectDelete("pms_eur_cur");
   ObjectDelete("pms_eur_pwr");

   ObjectDelete("pms_usd_1");
   ObjectDelete("pms_usd_2");
   ObjectDelete("pms_usd_3");
   ObjectDelete("pms_usd_4");
   ObjectDelete("pms_usd_5");
   ObjectDelete("pms_usd_6");
   ObjectDelete("pms_usd_7");
   ObjectDelete("pms_usd_8");
   ObjectDelete("pms_usd_9");
   ObjectDelete("pms_usd_10");
   ObjectDelete("pms_usd_cur");
   ObjectDelete("pms_usd_pwr");

   ObjectDelete("pms_gbp_1");
   ObjectDelete("pms_gbp_2");
   ObjectDelete("pms_gbp_3");
   ObjectDelete("pms_gbp_4");
   ObjectDelete("pms_gbp_5");
   ObjectDelete("pms_gbp_6");
   ObjectDelete("pms_gbp_7");
   ObjectDelete("pms_gbp_8");
   ObjectDelete("pms_gbp_9");
   ObjectDelete("pms_gbp_10");
   ObjectDelete("pms_gbp_cur");
   ObjectDelete("pms_gbp_pwr");

   ObjectDelete("pms_chf_1");
   ObjectDelete("pms_chf_2");
   ObjectDelete("pms_chf_3");
   ObjectDelete("pms_chf_4");
   ObjectDelete("pms_chf_5");
   ObjectDelete("pms_chf_6");
   ObjectDelete("pms_chf_7");
   ObjectDelete("pms_chf_8");
   ObjectDelete("pms_chf_9");
   ObjectDelete("pms_chf_10");
   ObjectDelete("pms_chf_cur");
   ObjectDelete("pms_chf_pwr");

   ObjectDelete("pms_jpy_1");
   ObjectDelete("pms_jpy_2");
   ObjectDelete("pms_jpy_3");
   ObjectDelete("pms_jpy_4");
   ObjectDelete("pms_jpy_5");
   ObjectDelete("pms_jpy_6");
   ObjectDelete("pms_jpy_7");
   ObjectDelete("pms_jpy_8");
   ObjectDelete("pms_jpy_9");
   ObjectDelete("pms_jpy_10");
   ObjectDelete("pms_jpy_cur");
   ObjectDelete("pms_jpy_pwr");

   ObjectDelete("pms_line_top");  
   ObjectDelete("pms_line_middle");  
   ObjectDelete("pms_line_bottom");
   ObjectDelete("pms_sign");
}

void objectCreate(string name,int x,int y,string text="-",int size=42,string font="Arial",color colour=CLR_NONE)
{
   ObjectCreate(name,OBJ_LABEL,0,0,0);
   ObjectSet(name,OBJPROP_CORNER,3);
   ObjectSet(name,OBJPROP_COLOR,colour);
   ObjectSet(name,OBJPROP_XDISTANCE,x);
   ObjectSet(name,OBJPROP_YDISTANCE,y);
   ObjectSetText(name,text,size,font,colour);
}

void objectBlank()
{
   ObjectSet("pms_eur_1",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_eur_2",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_eur_3",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_eur_4",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_eur_5",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_eur_6",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_eur_7",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_eur_8",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_eur_9",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_eur_10",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_eur_cur",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_eur_pwr",OBJPROP_COLOR,CLR_NONE);

   ObjectSet("pms_usd_1",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_usd_2",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_usd_3",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_usd_4",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_usd_5",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_usd_6",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_usd_7",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_usd_8",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_usd_9",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_usd_10",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_usd_cur",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_usd_pwr",OBJPROP_COLOR,CLR_NONE);

   ObjectSet("pms_gbp_1",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_gbp_2",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_gbp_3",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_gbp_4",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_gbp_5",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_gbp_6",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_gbp_7",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_gbp_8",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_gbp_9",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_gbp_10",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_gbp_cur",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_gbp_pwr",OBJPROP_COLOR,CLR_NONE);

   ObjectSet("pms_chf_1",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_chf_2",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_chf_3",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_chf_4",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_chf_5",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_chf_6",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_chf_7",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_chf_8",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_chf_9",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_chf_10",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_chf_cur",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_chf_pwr",OBJPROP_COLOR,CLR_NONE);

   ObjectSet("pms_jpy_1",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_jpy_2",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_jpy_3",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_jpy_4",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_jpy_5",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_jpy_6",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_jpy_7",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_jpy_8",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_jpy_9",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_jpy_10",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_jpy_cur",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_jpy_pwr",OBJPROP_COLOR,CLR_NONE);

   ObjectSet("pms_line_top",OBJPROP_COLOR,CLR_NONE);
   ObjectSet("pms_line_middle",OBJPROP_COLOR,CLR_NONE);
}

void paintEUR(double value)
{
   if (value > 0) ObjectSet("pms_eur_1",OBJPROP_COLOR,Red);
   if (value >= 1) ObjectSet("pms_eur_2",OBJPROP_COLOR,OrangeRed);
   if (value >= 2) ObjectSet("pms_eur_3",OBJPROP_COLOR,DarkOrange);
   if (value >= 3) ObjectSet("pms_eur_4",OBJPROP_COLOR,Orange);
   if (value >= 4) ObjectSet("pms_eur_5",OBJPROP_COLOR,Gold);
   if (value >= 5) ObjectSet("pms_eur_6",OBJPROP_COLOR,Yellow);
   if (value >= 6) ObjectSet("pms_eur_7",OBJPROP_COLOR,GreenYellow);
   if (value >= 7) ObjectSet("pms_eur_8",OBJPROP_COLOR,LawnGreen);
   if (value >= 8) ObjectSet("pms_eur_9",OBJPROP_COLOR,Chartreuse);
   if (value >= 9) ObjectSet("pms_eur_10",OBJPROP_COLOR,Lime);
   ObjectSet("pms_eur_cur",OBJPROP_COLOR,SkyBlue);
   ObjectSetText("pms_eur_pwr",DoubleToStr(value,1),8,"Arial Narrow",Silver);
}

void paintUSD(double value)
{
   if (value > 0) ObjectSet("pms_usd_1",OBJPROP_COLOR,Red);
   if (value >= 1) ObjectSet("pms_usd_2",OBJPROP_COLOR,OrangeRed);
   if (value >= 2) ObjectSet("pms_usd_3",OBJPROP_COLOR,DarkOrange);
   if (value >= 3) ObjectSet("pms_usd_4",OBJPROP_COLOR,Orange);
   if (value >= 4) ObjectSet("pms_usd_5",OBJPROP_COLOR,Gold);
   if (value >= 5) ObjectSet("pms_usd_6",OBJPROP_COLOR,Yellow);
   if (value >= 6) ObjectSet("pms_usd_7",OBJPROP_COLOR,GreenYellow);
   if (value >= 7) ObjectSet("pms_usd_8",OBJPROP_COLOR,LawnGreen);
   if (value >= 8) ObjectSet("pms_usd_9",OBJPROP_COLOR,Chartreuse);
   if (value >= 9) ObjectSet("pms_usd_10",OBJPROP_COLOR,Lime);
   ObjectSet("pms_usd_cur",OBJPROP_COLOR,SkyBlue);
   ObjectSetText("pms_usd_pwr",DoubleToStr(value,1),8,"Arial Narrow",Silver);
}

void paintGBP(double value)
{
   if (value > 0) ObjectSet("pms_gbp_1",OBJPROP_COLOR,Red);
   if (value >= 1) ObjectSet("pms_gbp_2",OBJPROP_COLOR,OrangeRed);
   if (value >= 2) ObjectSet("pms_gbp_3",OBJPROP_COLOR,DarkOrange);
   if (value >= 3) ObjectSet("pms_gbp_4",OBJPROP_COLOR,Orange);
   if (value >= 4) ObjectSet("pms_gbp_5",OBJPROP_COLOR,Gold);
   if (value >= 5) ObjectSet("pms_gbp_6",OBJPROP_COLOR,Yellow);
   if (value >= 6) ObjectSet("pms_gbp_7",OBJPROP_COLOR,GreenYellow);
   if (value >= 7) ObjectSet("pms_gbp_8",OBJPROP_COLOR,LawnGreen);
   if (value >= 8) ObjectSet("pms_gbp_9",OBJPROP_COLOR,Chartreuse);
   if (value >= 9) ObjectSet("pms_gbp_10",OBJPROP_COLOR,Lime);
   ObjectSet("pms_gbp_cur",OBJPROP_COLOR,SkyBlue);
   ObjectSetText("pms_gbp_pwr",DoubleToStr(value,1),8,"Arial Narrow",Silver);
}

void paintCHF(double value)
{
   if (value > 0) ObjectSet("pms_chf_1",OBJPROP_COLOR,Red);
   if (value >= 1) ObjectSet("pms_chf_2",OBJPROP_COLOR,OrangeRed);
   if (value >= 2) ObjectSet("pms_chf_3",OBJPROP_COLOR,DarkOrange);
   if (value >= 3) ObjectSet("pms_chf_4",OBJPROP_COLOR,Orange);
   if (value >= 4) ObjectSet("pms_chf_5",OBJPROP_COLOR,Gold);
   if (value >= 5) ObjectSet("pms_chf_6",OBJPROP_COLOR,Yellow);
   if (value >= 6) ObjectSet("pms_chf_7",OBJPROP_COLOR,GreenYellow);
   if (value >= 7) ObjectSet("pms_chf_8",OBJPROP_COLOR,LawnGreen);
   if (value >= 8) ObjectSet("pms_chf_9",OBJPROP_COLOR,Chartreuse);
   if (value >= 9) ObjectSet("pms_chf_10",OBJPROP_COLOR,Lime);
   ObjectSet("pms_chf_cur",OBJPROP_COLOR,SkyBlue);
   ObjectSetText("pms_chf_pwr",DoubleToStr(value,1),8,"Arial Narrow",Silver);
}

void paintJPY(double value)
{
   if (value > 0) ObjectSet("pms_jpy_1",OBJPROP_COLOR,Red);
   if (value >= 1) ObjectSet("pms_jpy_2",OBJPROP_COLOR,OrangeRed);
   if (value >= 2) ObjectSet("pms_jpy_3",OBJPROP_COLOR,DarkOrange);
   if (value >= 3) ObjectSet("pms_jpy_4",OBJPROP_COLOR,Orange);
   if (value >= 4) ObjectSet("pms_jpy_5",OBJPROP_COLOR,Gold);
   if (value >= 5) ObjectSet("pms_jpy_6",OBJPROP_COLOR,Yellow);
   if (value >= 6) ObjectSet("pms_jpy_7",OBJPROP_COLOR,GreenYellow);
   if (value >= 7) ObjectSet("pms_jpy_8",OBJPROP_COLOR,LawnGreen);
   if (value >= 8) ObjectSet("pms_jpy_9",OBJPROP_COLOR,Chartreuse);
   if (value >= 9) ObjectSet("pms_jpy_10",OBJPROP_COLOR,Lime);
   ObjectSet("pms_jpy_cur",OBJPROP_COLOR,SkyBlue);
   ObjectSetText("pms_jpy_pwr",DoubleToStr(value,1),8,"Arial Narrow",Silver);
}

void paintLine()
{
   ObjectSet("pms_line_top",OBJPROP_COLOR,DimGray);
   ObjectSet("pms_line_middle",OBJPROP_COLOR,DimGray);
}

